"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var observable_1 = require("tns-core-modules/data/observable");
var utils = require("tns-core-modules/utils/utils");
var fs = require("tns-core-modules/file-system/file-system");
var Mediafilepicker = (function (_super) {
    __extends(Mediafilepicker, _super);
    function Mediafilepicker() {
        var _this = _super.call(this) || this;
        _this.collections = utils.ios.collections;
        _this._mediaPickerIQDeligate = MediafilepickerIQMediaPickerControllerDelegate.initWithOwner(new WeakRef(_this));
        _this._mediaPickerDocumentDeligate = MediafilepickerDocumentPickerDelegate.initWithOwner(new WeakRef(_this));
        var docuPath = fs.knownFolders.documents();
        docuPath.getFolder("filepicker");
        return _this;
    }
    Mediafilepicker.prototype.openImagePicker = function (params) {
        var options = params.ios, t = this;
        var controller = IQMediaPickerController.alloc().init();
        controller.delegate = this._mediaPickerIQDeligate;
        controller.sourceType = 0;
        controller.mediaTypes = this.collections.jsArrayToNSArray([PHAssetMediaTypeImage]);
        if (options.isCaptureMood) {
            controller.sourceType = 1;
        }
        if (options.maxNumberFiles > 0) {
            controller.allowsPickingMultipleItems = true;
            controller.maximumItemCount = options.maxNumberFiles;
        }
        if (!options.isCaptureMood) {
            PHPhotoLibrary.requestAuthorization(function (status) {
                if (status === 3) {
                    t.presentViewController(controller);
                }
                else {
                    t.msg = "Permission Error!";
                    t.notify({
                        eventName: 'error',
                        object: t
                    });
                }
            });
        }
        else {
            this.presentViewController(controller);
        }
    };
    Mediafilepicker.prototype.openVideoPicker = function (params) {
        var options = params.ios, t = this;
        var controller = IQMediaPickerController.alloc().init();
        controller.delegate = this._mediaPickerIQDeligate;
        controller.mediaTypes = this.collections.jsArrayToNSArray([PHAssetMediaTypeVideo]);
        controller.sourceType = 0;
        if (options.isCaptureMood) {
            controller.sourceType = 1;
        }
        if (options.maxNumberFiles > 0) {
            controller.allowsPickingMultipleItems = true;
            controller.maximumItemCount = options.maxNumberFiles;
        }
        if (options.videoMaximumDuration > 0) {
            controller.videoMaximumDuration = options.videoMaximumDuration;
        }
        if (options.allowedVideoQualities) {
            if (options.allowedVideoQualities.length > 0) {
                controller.allowedVideoQualities = this.collections.jsArrayToNSArray(options.allowedVideoQualities);
            }
        }
        if (!options.isCaptureMood) {
            PHPhotoLibrary.requestAuthorization(function (status) {
                if (status === 3) {
                    t.presentViewController(controller);
                }
                else {
                    t.msg = "Permission Error!";
                    t.notify({
                        eventName: 'error',
                        object: t
                    });
                }
            });
        }
        else {
            this.presentViewController(controller);
        }
    };
    Mediafilepicker.prototype.openAudioPicker = function (params) {
        var options = params.ios, t = this;
        var controller = IQMediaPickerController.alloc().init();
        controller.delegate = this._mediaPickerIQDeligate;
        controller.mediaTypes = this.collections.jsArrayToNSArray([PHAssetMediaTypeAudio]);
        controller.sourceType = 0;
        if (options.isCaptureMood) {
            controller.sourceType = 1;
        }
        if (options.maxNumberFiles > 0) {
            controller.allowsPickingMultipleItems = true;
            controller.maximumItemCount = options.maxNumberFiles;
        }
        if (options.audioMaximumDuration > 0) {
            controller.audioMaximumDuration = options.audioMaximumDuration;
        }
        if (!options.isCaptureMood) {
            MPMediaLibrary.requestAuthorization(function (status) {
                if (status === 3) {
                    t.presentViewController(controller);
                }
                else {
                    t.msg = "Permission Error!";
                    t.notify({
                        eventName: 'error',
                        object: t
                    });
                }
            });
        }
        else {
            this.presentViewController(controller);
        }
    };
    Mediafilepicker.prototype.openFilePicker = function (params) {
        var options = params.ios;
        var documentTypes;
        if (options.extensions) {
            if (options.extensions.length > 0) {
                documentTypes = this.collections.jsArrayToNSArray(options.extensions);
            }
        }
        var controller = UIDocumentPickerViewController.alloc().initWithDocumentTypesInMode(documentTypes, 0);
        controller.delegate = this._mediaPickerDocumentDeligate;
        if (options.multipleSelection) {
            controller.allowsMultipleSelection = true;
        }
        this.presentViewController(controller);
    };
    Mediafilepicker.prototype.copyPHImageToAppDirectory = function (rawData, fileName) {
        return new Promise(function (resolve, reject) {
            var docuPath = fs.knownFolders.documents();
            var targetImgeURL = docuPath.path + "/filepicker/" + fileName;
            var output = {
                status: false,
                msg: 'error',
                file: ''
            };
            var options = PHImageRequestOptions.alloc().init();
            options.synchronous = true;
            PHImageManager.defaultManager().requestImageDataForAssetOptionsResultHandler(rawData, options, function (imageData, dataUTI, orientation, info) {
                var newData = imageData;
                if (newData) {
                    try {
                        newData.writeToFileAtomically(targetImgeURL, true);
                        output = {
                            status: true,
                            msg: 'success',
                            file: targetImgeURL.toString()
                        };
                        resolve(output);
                    }
                    catch (e) {
                        output.msg = e;
                        reject(output);
                    }
                }
            });
        });
    };
    Mediafilepicker.prototype.copyPHVideoToAppDirectory = function (urlAsset, fileName) {
        return new Promise(function (resolve, reject) {
            var docuPath = fs.knownFolders.documents();
            var output = {
                status: false,
                msg: 'error',
                file: ''
            };
            if (fs.File.exists(docuPath.path + "/filepicker/" + fileName)) {
                docuPath.getFile("filepicker/" + fileName).remove();
            }
            var targetURL = NSURL.fileURLWithPath(docuPath.path + "/filepicker/" + fileName);
            try {
                var write_1 = NSFileManager.defaultManager.copyItemAtURLToURLError(urlAsset.URL, targetURL);
                if (write_1) {
                    output = {
                        status: true,
                        msg: 'success',
                        file: targetURL.toString()
                    };
                    resolve(output);
                }
                else {
                    output.msg = "Not copied";
                    reject(output);
                }
            }
            catch (e) {
                output.msg = e;
                reject(output);
            }
        });
    };
    Mediafilepicker.prototype.convertPHImageToUIImage = function (rawData) {
        return new Promise(function (resolve, reject) {
            var options = PHImageRequestOptions.new();
            options.resizeMode = 1;
            options.synchronous = true;
            PHImageManager.defaultManager().requestImageForAssetTargetSizeContentModeOptionsResultHandler(rawData, PHImageManagerMaximumSize, 1, options, function (result, info) {
                if (result) {
                    resolve(result);
                }
                else {
                    reject("something went wrong!");
                }
            });
        });
    };
    Mediafilepicker.prototype.copyUIImageToAppDirectory = function (image, fileName) {
        return new Promise(function (resolve, reject) {
            var data = UIImageJPEGRepresentation(image, 1);
            var docuPath = fs.knownFolders.documents();
            var targetImgeURL = docuPath.path + "/filepicker/" + fileName;
            if (fs.File.exists(docuPath.path + "/filepicker/" + fileName)) {
                docuPath.getFile("filepicker/" + fileName).remove();
            }
            var output = {
                status: false,
                msg: 'error',
                file: ''
            };
            try {
                data.writeToFileAtomically(targetImgeURL, true);
                output = {
                    status: true,
                    msg: 'success',
                    file: targetImgeURL.toString()
                };
                resolve(output);
            }
            catch (e) {
                output.msg = e;
                reject(output);
            }
        });
    };
    Mediafilepicker.prototype.presentViewController = function (controller) {
        var app = utils.ios.getter(UIApplication, UIApplication.sharedApplication);
        app.keyWindow.rootViewController.presentViewControllerAnimatedCompletion(controller, true, null);
    };
    Mediafilepicker.prototype.greet = function () {
        return "Hello, NS";
    };
    return Mediafilepicker;
}(observable_1.Observable));
exports.Mediafilepicker = Mediafilepicker;
var MediafilepickerIQMediaPickerControllerDelegate = (function (_super) {
    __extends(MediafilepickerIQMediaPickerControllerDelegate, _super);
    function MediafilepickerIQMediaPickerControllerDelegate() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MediafilepickerIQMediaPickerControllerDelegate.initWithOwner = function (owner) {
        var deligate = _super.new.call(this);
        deligate._owner = owner;
        return deligate;
    };
    MediafilepickerIQMediaPickerControllerDelegate.prototype.mediaPickerControllerDidFinishMedias = function (controller, selectedMedias) {
        var t = this._owner.get(), output = [];
        if (selectedMedias.selectedAssets.count > 0) {
            var results = selectedMedias.selectedAssets;
            var _loop_1 = function (i) {
                var result = results[i];
                if (result.mediaType === PHAssetMediaTypeImage) {
                    var _uriRequestOptions = PHImageRequestOptions.alloc().init();
                    _uriRequestOptions.synchronous = true;
                    PHImageManager.defaultManager().requestImageDataForAssetOptionsResultHandler(result, _uriRequestOptions, function (data, uti, orientation, info) {
                        var uri = info.objectForKey("PHImageFileURLKey");
                        var fileUrl;
                        if (uri) {
                            fileUrl = uri.toString();
                        }
                        var file = {
                            type: 'image',
                            file: fileUrl,
                            rawData: result
                        };
                        output.push(file);
                    });
                }
                else if (result.mediaType === PHAssetMediaTypeVideo) {
                    var options = PHVideoRequestOptions.new();
                    options.deliveryMode = 1;
                    PHImageManager.defaultManager().requestAVAssetForVideoOptionsResultHandler(result, options, function (asset, audioMix, info) {
                        var urlAsset = asset;
                        var url;
                        if (urlAsset.URL) {
                            url = urlAsset.URL;
                        }
                        var file = {
                            type: 'image',
                            file: url.absoluteString,
                            rawData: result,
                            urlAsset: urlAsset
                        };
                        output.push(file);
                    });
                }
            };
            for (var i = 0; i < results.count; i++) {
                _loop_1(i);
            }
        }
        else if (selectedMedias.selectedAudios.count > 0) {
            var results = selectedMedias.selectedAudios;
            for (var i = 0; i < results.count; i++) {
                var result = results[i];
                var file = {
                    type: 'audio',
                    file: result.assetURL.toString(),
                    rawData: result
                };
                output.push(file);
            }
        }
        else if (selectedMedias.selectedAssetsURL.count > 0) {
            var results = selectedMedias.selectedAssetsURL;
            for (var i = 0; i < results.count; i++) {
                var result = results[i];
                var file = {
                    type: 'recorded',
                    file: result.relativePath,
                    rawData: result
                };
                output.push(file);
            }
        }
        else if (selectedMedias.selectedImages.count) {
            var results = selectedMedias.selectedImages;
            for (var i = 0; i < results.count; i++) {
                var result = results[i];
                var file = {
                    type: 'capturedImage',
                    file: result,
                    rawData: result
                };
                output.push(file);
            }
        }
        setTimeout(function () {
            t.results = output;
            if (output.length > 0) {
                t.notify({
                    eventName: 'getFiles',
                    object: t
                });
            }
            else {
                t.msg = "No file!";
                t.notify({
                    eventName: 'error',
                    object: t
                });
            }
        }, 1000);
    };
    MediafilepickerIQMediaPickerControllerDelegate.prototype.mediaPickerControllerDidCancel = function (controller) {
        this._owner.get().msg = 'Picker cancel';
        this._owner.get().notify({
            eventName: 'cancel',
            object: this._owner.get()
        });
    };
    MediafilepickerIQMediaPickerControllerDelegate.ObjCProtocols = [IQMediaPickerControllerDelegate];
    return MediafilepickerIQMediaPickerControllerDelegate;
}(NSObject));
exports.MediafilepickerIQMediaPickerControllerDelegate = MediafilepickerIQMediaPickerControllerDelegate;
var MediafilepickerDocumentPickerDelegate = (function (_super) {
    __extends(MediafilepickerDocumentPickerDelegate, _super);
    function MediafilepickerDocumentPickerDelegate() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MediafilepickerDocumentPickerDelegate.initWithOwner = function (owner) {
        var delegate = MediafilepickerDocumentPickerDelegate.new();
        delegate._owner = owner;
        return delegate;
    };
    MediafilepickerDocumentPickerDelegate.prototype.documentPickerDidPickDocumentAtURL = function (controller, url) {
        var t = this._owner.get();
        setTimeout(function () {
            if (url) {
                var file = {
                    type: 'normalFile',
                    file: url.absoluteString,
                    rawData: url
                };
                t.results = [file];
                t.notify({
                    eventName: 'getFiles',
                    object: t
                });
            }
            else {
                t.msg = "No file!";
                t.notify({
                    eventName: 'error',
                    object: t
                });
            }
        }, 1000);
    };
    MediafilepickerDocumentPickerDelegate.prototype.documentPickerDidPickDocumentsAtURLs = function (controller, urls) {
        var output = [];
        var t = this._owner.get();
        if (urls.count > 0) {
            for (var i = 0; i < urls.count; i++) {
                var url = urls[i];
                var file = {
                    type: 'normalFile',
                    file: url.absoluteString,
                    rawData: url
                };
                output.push(file);
            }
        }
        setTimeout(function () {
            t.results = output;
            if (output.length > 0) {
                t.notify({
                    eventName: 'getFiles',
                    object: t
                });
            }
            else {
                t.msg = "No file!";
                t.notify({
                    eventName: 'error',
                    object: t
                });
            }
        }, 1000);
    };
    MediafilepickerDocumentPickerDelegate.prototype.documentPickerWasCancelled = function (controller) {
        this._owner.get().msg = 'Picker cancel';
        this._owner.get().notify({
            eventName: 'cancel',
            object: this._owner.get()
        });
    };
    MediafilepickerDocumentPickerDelegate.ObjCProtocols = [UIDocumentPickerDelegate];
    return MediafilepickerDocumentPickerDelegate;
}(NSObject));
//# sourceMappingURL=mediafilepicker.ios.js.map